@@ -24,9 +24,11 @@ from ctypes import CDLL, byref, create_string_buffer
 from ctypes.util import find_library
 from packaging.version import Version as V
 
+import gajim.gui
 from gajim.common import i18n
 
-_MIN_NBXMPP_VER = '0.9.94'
+
+_MIN_NBXMPP_VER = '2.0.1'
 _MIN_GTK_VER = '3.22.27'
 _MIN_CAIRO_VER = '1.16.0'
 _MIN_PYGOBJECT_VER = '3.32.0'
@@ -94,7 +96,7 @@ def _disable_csd():
     if sys.platform != 'win32':
         return
 
-    if 'GTK_OSD' in os.environ:
+    if 'GTK_CSD' in os.environ:
         # Respect user settings
         return
 
@@ -102,13 +104,16 @@ def _disable_csd():
 
 
 def _init_gtk():
-    from gajim.gtk import exception
+    gajim.gui.init('gtk')
+
+    from gajim.gui import exception
     exception.init()
 
     i18n.initialize_direction_mark()
 
-    from gajim.application import GajimApplication
 
+def _run_app():
+    from gajim.application import GajimApplication
     application = GajimApplication()
     _install_sginal_handlers(application)
     application.run(sys.argv)
@@ -152,3 +157,4 @@ def main():
     _set_proc_title()
     _disable_csd()
     _init_gui('GTK')
+    _run_app()
