@@ -23,7 +23,8 @@
 
 import time
 import datetime
-from enum import IntEnum, unique
+from enum import IntEnum
+from enum import unique
 
 from gi.repository import Gtk
 from gi.repository import Gdk
@@ -39,9 +40,16 @@ from gajim.common.const import StyleAttr
 
 from gajim import conversation_textview
 
-from gajim.gtk import util
-from gajim.gtk.util import python_month, gtk_month
-from gajim.gtk.dialogs import ErrorDialog
+from .util import python_month
+from .util import gtk_month
+from .util import resize_window
+from .util import move_window
+from .util import get_icon_name
+from .util import get_completion_liststore
+from .util import get_builder
+from .util import scroll_to_end
+
+from .dialogs import ErrorDialog
 
 @unique
 class InfoColumn(IntEnum):
@@ -62,47 +70,34 @@ class Column(IntEnum):
     LOG_LINE_ID = 5
 
 
-class HistoryWindow:
-    """
-    Class for browsing logs of conversations with contacts
-    """
-
+class HistoryWindow(Gtk.ApplicationWindow):
     def __init__(self, jid=None, account=None):
-        xml = util.get_builder('history_window.ui')
-        self.window = xml.get_object('history_window')
-        self.window.set_application(app.app)
-        self.calendar = xml.get_object('calendar')
-        self.button_first_day = xml.get_object('button_first_day')
-        self.button_previous_day = xml.get_object('button_previous_day')
-        self.button_next_day = xml.get_object('button_next_day')
-        self.button_last_day = xml.get_object('button_last_day')
-        scrolledwindow = xml.get_object('scrolledwindow')
+        Gtk.ApplicationWindow.__init__(self)
+        self.set_application(app.app)
+        self.set_position(Gtk.WindowPosition.CENTER)
+        self.set_show_menubar(False)
+        self.set_title(_('Conversation History'))
+
+        self._ui = get_builder('history_window.ui')
+
+        self.add(self._ui.history_box)
+
         self.history_textview = conversation_textview.ConversationTextview(
             account, used_in_history_window=True)
-        scrolledwindow.add(self.history_textview.tv)
+        self._ui.scrolledwindow.add(self.history_textview.tv)
         self.history_buffer = self.history_textview.tv.get_buffer()
         highlight_color = app.css_config.get_value(
-            '.gajim-highlight-message', StyleAttr.COLOR)
+            '.gajim-search-highlight', StyleAttr.COLOR)
         self.history_buffer.create_tag('highlight', background=highlight_color)
         self.history_buffer.create_tag('invisible', invisible=True)
-        self.checkbutton = xml.get_object('log_history_checkbutton')
-        self.show_status_checkbutton = xml.get_object('show_status_checkbutton')
-        self.search_entry = xml.get_object('search_entry')
-        self.query_liststore = xml.get_object('query_liststore')
-        self.jid_entry = xml.get_object('query_entry')
-        self.results_treeview = xml.get_object('results_treeview')
-        self.results_window = xml.get_object('results_scrolledwindow')
-        self.search_in_date = xml.get_object('search_in_date')
-        self.date_label = xml.get_object('date_label')
-        self.search_menu_button = xml.get_object('search_menu_button')
 
         self.clearing_search = False
 
         # jid, contact_name, date, message, time, log_line_id
         model = Gtk.ListStore(str, str, str, str, str, int)
-        self.results_treeview.set_model(model)
+        self._ui.results_treeview.set_model(model)
         col = Gtk.TreeViewColumn(_('Name'))
-        self.results_treeview.append_column(col)
+        self._ui.results_treeview.append_column(col)
         renderer = Gtk.CellRendererText()
         col.pack_start(renderer, True)
         col.add_attribute(renderer, 'text', Column.CONTACT_NAME)
@@ -111,7 +106,7 @@ class HistoryWindow:
         col.set_resizable(True)
 
         col = Gtk.TreeViewColumn(_('Date'))
-        self.results_treeview.append_column(col)
+        self._ui.results_treeview.append_column(col)
         renderer = Gtk.CellRendererText()
         col.pack_start(renderer, True)
         col.add_attribute(renderer, 'text', Column.UNIXTIME)
@@ -120,7 +115,7 @@ class HistoryWindow:
         col.set_resizable(True)
 
         col = Gtk.TreeViewColumn(_('Message'))
-        self.results_treeview.append_column(col)
+        self._ui.results_treeview.append_column(col)
         renderer = Gtk.CellRendererText()
         col.pack_start(renderer, True)
         col.add_attribute(renderer, 'text', Column.MESSAGE)
@@ -137,19 +132,22 @@ class HistoryWindow:
         GLib.idle_add(next, task)
 
         if jid:
-            self.jid_entry.get_child().set_text(jid)
+            self._ui.query_entry.get_child().set_text(jid)
         else:
             self._load_history(None)
 
-        util.resize_window(self.window,
-                           app.config.get('history_window_width'),
-                           app.config.get('history_window_height'))
-        util.move_window(self.window,
-                         app.config.get('history_window_x-position'),
-                         app.config.get('history_window_y-position'))
+        resize_window(self,
+                      app.settings.get('history_window_width'),
+                      app.settings.get('history_window_height'))
+        move_window(self,
+                    app.settings.get('history_window_x-position'),
+                    app.settings.get('history_window_y-position'))
 
-        xml.connect_signals(self)
-        self.window.show_all()
+        self._ui.connect_signals(self)
+        self.connect('delete-event', self._on_delete)
+        self.connect('destroy', self._on_destroy)
+        self.connect('key-press-event', self._on_key_press)
+        self.show_all()
 
         # PluginSystem: adding GUI extension point for
         # HistoryWindow instance object
@@ -167,16 +165,16 @@ class HistoryWindow:
         {key : (jid, account, nick_name, full_completion_name}
         This is a generator and does pseudo-threading via idle_add().
         """
-        liststore = util.get_completion_liststore(
-            self.jid_entry.get_child())
+        liststore = get_completion_liststore(
+            self._ui.query_entry.get_child())
         liststore.set_sort_column_id(1, Gtk.SortType.ASCENDING)
-        self.jid_entry.get_child().get_completion().connect(
+        self._ui.query_entry.get_child().get_completion().connect(
             'match-selected', self.on_jid_entry_match_selected)
 
-        self.jid_entry.set_model(liststore)
+        self._ui.query_entry.set_model(liststore)
 
         # Add all jids in logs.db:
-        db_jids = app.logger.get_jids_in_db()
+        db_jids = app.storage.archive.get_jids_in_db()
         completion_dict = dict.fromkeys(db_jids)
 
         self.accounts_seen_online = list(app.contacts.get_accounts())
@@ -187,12 +185,12 @@ class HistoryWindow:
             completion_dict.update(
                 helpers.get_contact_dict_for_account(account))
 
-        muc_active_icon = util.get_iconset_name_for('muc-active')
-        online_icon = util.get_iconset_name_for('online')
+        muc_active_icon = get_icon_name('muc-active')
+        online_icon = get_icon_name('online')
 
         keys = list(completion_dict.keys())
         # Move the actual jid at first so we load history faster
-        actual_jid = self.jid_entry.get_child().get_text()
+        actual_jid = self._ui.query_entry.get_child().get_text()
         if actual_jid in keys:
             keys.remove(actual_jid)
             keys.insert(0, actual_jid)
@@ -218,10 +216,10 @@ class HistoryWindow:
 
             info_acc = self._get_account_for_jid(info_jid)
 
-            if (app.logger.jid_is_room_jid(completed) or
-                    app.logger.jid_is_from_pm(completed)):
+            if (app.storage.archive.jid_is_room_jid(completed) or
+                    app.storage.archive.jid_is_from_pm(completed)):
                 icon = muc_active_icon
-                if app.logger.jid_is_from_pm(completed):
+                if app.storage.archive.jid_is_from_pm(completed):
                     # It's PM. Make it easier to find
                     room, nick = app.get_room_and_nick_from_fjid(completed)
                     info_completion = '%s from %s' % (nick, room)
@@ -266,21 +264,23 @@ class HistoryWindow:
                 break
         return account
 
-    def on_history_window_delete_event(self, widget, *args):
+    def _on_delete(self, widget, *args):
         self.save_state()
 
-    def on_history_window_destroy(self, widget):
+    def _on_destroy(self, widget):
         # PluginSystem: removing GUI extension points connected with
         # HistoryWindow instance object
         app.plugin_manager.remove_gui_extension_point(
             'history_window', self)
         self.history_textview.del_handlers()
-        del app.interface.instances['logs']
 
-    def on_history_window_key_press_event(self, widget, event):
+    def _on_key_press(self, widget, event):
         if event.keyval == Gdk.KEY_Escape:
+            if self._ui.results_scrolledwindow.get_visible():
+                self._ui.results_scrolledwindow.set_visible(False)
+                return
             self.save_state()
-            self.window.destroy()
+            self.destroy()
 
     def on_jid_entry_match_selected(self, widget, model, iter_, *args):
         self._jid_entry_search(model[iter_][1])
@@ -288,16 +288,16 @@ class HistoryWindow:
 
     def on_jid_entry_changed(self, widget):
         # only if selected from combobox
-        jid = self.jid_entry.get_child().get_text()
-        if jid == self.jid_entry.get_active_id():
+        jid = self._ui.query_entry.get_child().get_text()
+        if jid == self._ui.query_entry.get_active_id():
             self._jid_entry_search(jid)
 
     def on_jid_entry_activate(self, widget):
-        self._jid_entry_search(self.jid_entry.get_child().get_text())
+        self._jid_entry_search(self._ui.query_entry.get_child().get_text())
 
     def _jid_entry_search(self, jid):
         self._load_history(jid, self.account)
-        self.results_window.set_property('visible', False)
+        self._ui.results_scrolledwindow.set_visible(False)
 
     def _load_history(self, jid_or_name, account=None):
         """
@@ -317,47 +317,47 @@ class HistoryWindow:
                 # We don't know account. Probably a gc not opened or an
                 # account not connected.
                 # Disable possibility to say if we want to log or not
-                self.checkbutton.set_sensitive(False)
+                self._ui.log_history_checkbutton.set_sensitive(False)
             else:
                 # Are log disabled for account ?
-                if self.account in app.config.get_per(
-                        'accounts', self.account, 'no_log_for').split(' '):
-                    self.checkbutton.set_active(False)
-                    self.checkbutton.set_sensitive(False)
+                if self.account in app.settings.get_account_setting(
+                        self.account, 'no_log_for').split(' '):
+                    self._ui.log_history_checkbutton.set_active(False)
+                    self._ui.log_history_checkbutton.set_sensitive(False)
                 else:
                     # Are log disabled for jid ?
                     log = True
-                    if self.jid in app.config.get_per(
-                            'accounts', self.account, 'no_log_for').split(' '):
+                    if self.jid in app.settings.get_account_setting(
+                            self.account, 'no_log_for').split(' '):
                         log = False
-                    self.checkbutton.set_active(log)
-                    self.checkbutton.set_sensitive(True)
+                    self._ui.log_history_checkbutton.set_active(log)
+                    self._ui.log_history_checkbutton.set_sensitive(True)
 
             self.jids_to_search = [info_jid]
 
             # Get first/last date we have logs with contact
-            self.first_log = app.logger.get_first_date_that_has_logs(
+            self.first_log = app.storage.archive.get_first_date_that_has_logs(
                 self.account, self.jid)
             self.first_day = self._get_date_from_timestamp(self.first_log)
-            self.last_log = app.logger.get_last_date_that_has_logs(
+            self.last_log = app.storage.archive.get_last_date_that_has_logs(
                 self.account, self.jid)
             self.last_day = self._get_date_from_timestamp(self.last_log)
 
             # Select logs for last date we have logs with contact
-            self.search_menu_button.set_sensitive(True)
+            self._ui.search_menu_button.set_sensitive(True)
             month = gtk_month(self.last_day.month)
-            self.calendar.select_month(month, self.last_day.year)
-            self.calendar.select_day(self.last_day.day)
+            self._ui.calendar.select_month(month, self.last_day.year)
+            self._ui.calendar.select_day(self.last_day.day)
 
-            self.button_previous_day.set_sensitive(True)
-            self.button_next_day.set_sensitive(True)
-            self.button_first_day.set_sensitive(True)
-            self.button_last_day.set_sensitive(True)
+            self._ui.button_previous_day.set_sensitive(True)
+            self._ui.button_next_day.set_sensitive(True)
+            self._ui.button_first_day.set_sensitive(True)
+            self._ui.button_last_day.set_sensitive(True)
 
-            self.search_entry.set_sensitive(True)
-            self.search_entry.grab_focus()
+            self._ui.search_entry.set_sensitive(True)
+            self._ui.search_entry.grab_focus()
 
-            self.jid_entry.get_child().set_text(info_completion)
+            self._ui.query_entry.get_child().set_text(info_completion)
 
         else:
             # neither a valid jid, nor an existing contact name was entered
@@ -366,26 +366,27 @@ class HistoryWindow:
             self.account = None
 
             self.history_buffer.set_text('')  # clear the buffer
-            self.search_entry.set_sensitive(False)
+            self._ui.search_entry.set_sensitive(False)
 
-            self.checkbutton.set_sensitive(False)
-            self.search_menu_button.set_sensitive(False)
-            self.calendar.clear_marks()
-            self.button_previous_day.set_sensitive(False)
-            self.button_next_day.set_sensitive(False)
-            self.button_first_day.set_sensitive(False)
-            self.button_last_day.set_sensitive(False)
+            self._ui.log_history_checkbutton.set_sensitive(False)
+            self._ui.search_menu_button.set_sensitive(False)
+            self._ui.calendar.clear_marks()
+            self._ui.button_previous_day.set_sensitive(False)
+            self._ui.button_next_day.set_sensitive(False)
+            self._ui.button_first_day.set_sensitive(False)
+            self._ui.button_last_day.set_sensitive(False)
 
-            self.results_window.set_property('visible', False)
+            self._ui.results_scrolledwindow.set_visible(False)
 
     def on_calendar_day_selected(self, widget):
         if not self.jid:
             return
-        year, month, day = self.calendar.get_date()  # integers
+        year, month, day = self._ui.calendar.get_date()  # integers
         month = python_month(month)
         date_str = datetime.date(year, month, day).strftime('%x')
-        self.date_label.set_text(date_str)
+        self._ui.date_label.set_text(date_str)
         self._load_conversation(year, month, day)
+        GLib.idle_add(scroll_to_end, self._ui.scrolledwindow)
 
     def on_calendar_month_changed(self, widget):
         """
@@ -404,7 +405,7 @@ class HistoryWindow:
         month = python_month(month)
 
         try:
-            log_days = app.logger.get_days_with_logs(
+            log_days = app.storage.archive.get_days_with_logs(
                 self.account, self.jid, year, month)
         except exceptions.PysqliteOperationalError as error:
             ErrorDialog(_('Disk Error'), str(error))
@@ -422,29 +423,29 @@ class HistoryWindow:
 
     def _change_date(self, widget):
         # Get day selected in calendar
-        y, m, d = self.calendar.get_date()
+        y, m, d = self._ui.calendar.get_date()
         py_m = python_month(m)
         _date = datetime.datetime(y, py_m, d)
 
-        if widget is self.button_first_day:
+        if widget is self._ui.button_first_day:
             gtk_m = gtk_month(self.first_day.month)
-            self.calendar.select_month(gtk_m, self.first_day.year)
-            self.calendar.select_day(self.first_day.day)
+            self._ui.calendar.select_month(gtk_m, self.first_day.year)
+            self._ui.calendar.select_day(self.first_day.day)
             return
 
-        if widget is self.button_last_day:
+        if widget is self._ui.button_last_day:
             gtk_m = gtk_month(
                 self.last_day.month)
-            self.calendar.select_month(gtk_m, self.last_day.year)
-            self.calendar.select_day(self.last_day.day)
+            self._ui.calendar.select_month(gtk_m, self.last_day.year)
+            self._ui.calendar.select_day(self.last_day.day)
             return
 
-        if widget is self.button_previous_day:
+        if widget is self._ui.button_previous_day:
             end_date = self.first_day
             timedelta = datetime.timedelta(days=-1)
             if end_date >= _date:
                 return
-        elif widget is self.button_next_day:
+        elif widget is self._ui.button_next_day:
             end_date = self.last_day
             timedelta = datetime.timedelta(days=1)
             if end_date <= _date:
@@ -458,15 +459,15 @@ class HistoryWindow:
             if _date == end_date:
                 break
             try:
-                logs = app.logger.get_date_has_logs(
+                logs = app.storage.archive.get_date_has_logs(
                     self.account, self.jid, _date)
             except exceptions.PysqliteOperationalError as e:
                 ErrorDialog(_('Disk Error'), str(e))
                 return
 
         gtk_m = gtk_month(_date.month)
-        self.calendar.select_month(gtk_m, _date.year)
-        self.calendar.select_day(_date.day)
+        self._ui.calendar.select_month(gtk_m, _date.year)
+        self._ui.calendar.select_day(_date.day)
 
     def _get_string_show_from_constant_int(self, show):
         if show == ShowConstant.ONLINE:
@@ -492,11 +493,11 @@ class HistoryWindow:
         """
         self.history_buffer.set_text('')
         self.last_time_printout = 0
-        show_status = self.show_status_checkbutton.get_active()
+        show_status = self._ui.show_status_checkbutton.get_active()
 
         date = datetime.datetime(year, month, day)
 
-        conversation = app.logger.get_conversation_for_date(
+        conversation = app.storage.archive.get_conversation_for_date(
             self.account, self.jid, date)
 
         for message in conversation:
@@ -525,13 +526,13 @@ class HistoryWindow:
         # Make the beginning of every message searchable by its log_line_id
         buf.create_mark(str(log_line_id), end_iter, left_gravity=True)
 
-        if app.config.get('print_time') == 'always':
-            timestamp_str = app.config.get('time_stamp')
+        if app.settings.get('print_time') == 'always':
+            timestamp_str = app.settings.get('time_stamp')
             timestamp_str = helpers.from_one_line(timestamp_str)
             tim = time.strftime(timestamp_str, time.localtime(float(tim)))
             buf.insert(end_iter, tim)
-        elif app.config.get('print_time') == 'sometimes':
-            every_foo_seconds = 60 * app.config.get(
+        elif app.settings.get('print_time') == 'sometimes':
+            every_foo_seconds = 60 * app.settings.get(
                 'print_ichat_every_foo_minutes')
             seconds_passed = tim - self.last_time_printout
             if seconds_passed > every_foo_seconds:
@@ -604,9 +605,9 @@ class HistoryWindow:
             # eg. nkour: nkour is now Offline
             if contact_name and kind != KindConstant.GCSTATUS:
                 # add stuff before and after contact name
-                before_str = app.config.get('before_nickname')
+                before_str = app.settings.get('before_nickname')
                 before_str = helpers.from_one_line(before_str)
-                after_str = app.config.get('after_nickname')
+                after_str = app.settings.get('after_nickname')
                 after_str = helpers.from_one_line(after_str)
                 format_ = before_str + contact_name + after_str + ' '
                 if tag_name:
@@ -615,34 +616,30 @@ class HistoryWindow:
                     buf.insert(end_iter, format_)
         if subject:
             message = _('Subject: %s\n') % subject + message
-        xhtml = None
-        if message.startswith('<body '):
-            xhtml = message
 
         if tag_msg:
             self.history_textview.print_real_text(
-                message, [tag_msg],
+                message,
+                [tag_msg],
                 name=contact_name,
-                xhtml=xhtml,
                 additional_data=additional_data)
         else:
             self.history_textview.print_real_text(
                 message,
                 name=contact_name,
-                xhtml=xhtml,
                 additional_data=additional_data)
         self.history_textview.print_real_text('\n', text_tags=['eol'])
 
     def on_search_complete_history_toggled(self, widget):
-        self.date_label.get_style_context().remove_class('tagged')
+        self._ui.date_label.get_style_context().remove_class('tagged')
 
     def on_search_in_date_toggled(self, widget):
-        self.date_label.get_style_context().add_class('tagged')
+        self._ui.date_label.get_style_context().add_class('tagged')
 
     def on_search_entry_activate(self, widget):
-        text = self.search_entry.get_text()
+        text = self._ui.search_entry.get_text()
 
-        model = self.results_treeview.get_model()
+        model = self._ui.results_treeview.get_model()
         self.clearing_search = True
         model.clear()
         self.clearing_search = False
@@ -652,10 +649,10 @@ class HistoryWindow:
         self.history_buffer.remove_tag_by_name('highlight', start, end)
 
         if text == '':
-            self.results_window.set_property('visible', False)
+            self._ui.results_scrolledwindow.set_visible(False)
             return
 
-        self.results_window.set_property('visible', True)
+        self._ui.results_scrolledwindow.set_visible(True)
 
         # perform search in preselected jids
         # jids are preselected with the query_entry
@@ -669,14 +666,14 @@ class HistoryWindow:
                 account = list(app.contacts.get_accounts())[0]
 
             date = None
-            if self.search_in_date.get_active():
-                year, month, day = self.calendar.get_date()  # integers
+            if self._ui.search_in_date.get_active():
+                year, month, day = self._ui.calendar.get_date()  # integers
                 month = python_month(month)
                 date = datetime.datetime(year, month, day)
 
-            show_status = self.show_status_checkbutton.get_active()
+            show_status = self._ui.show_status_checkbutton.get_active()
 
-            results = app.logger.search_log(account, jid, text, date)
+            results = app.storage.archive.search_log(account, jid, text, date)
             result_found = False
             # FIXME:
             # add "subject:  | message: " in message column if kind is single
@@ -701,7 +698,7 @@ class HistoryWindow:
                               str(row.time), row.log_line_id))
 
             if result_found:
-                self.results_treeview.set_cursor(0)
+                self._ui.results_treeview.set_cursor(0)
 
     def on_results_treeview_cursor_changed(self, *args):
         """
@@ -712,9 +709,9 @@ class HistoryWindow:
             return
 
         # get currently selected date
-        cur_year, cur_month, cur_day = self.calendar.get_date()
+        cur_year, cur_month, cur_day = self._ui.calendar.get_date()
         cur_month = python_month(cur_month)
-        model, paths = self.results_treeview.get_selection().get_selected_rows()
+        model, paths = self._ui.results_treeview.get_selection().get_selected_rows()
 
         if not paths:
             return
@@ -732,12 +729,12 @@ class HistoryWindow:
         if log_jid != self.jid:
             self._load_history(log_jid, None)
 
-        # avoid reruning mark days algo if same month and year!
+        # avoid rerunning mark days algo if same month and year!
         if year != cur_year or gtk_m != cur_month:
-            self.calendar.select_month(month, year)
+            self._ui.calendar.select_month(month, year)
 
         if year != cur_year or gtk_m != cur_month or day != cur_day:
-            self.calendar.select_day(day)
+            self._ui.calendar.select_day(day)
 
         self._scroll_to_message_and_highlight(model[path][Column.LOG_LINE_ID])
 
@@ -777,8 +774,8 @@ class HistoryWindow:
     def on_log_history_checkbutton_toggled(self, widget, *args):
         # log conversation history?
         oldlog = True
-        no_log_for = app.config.get_per(
-            'accounts', self.account, 'no_log_for').split()
+        no_log_for = app.settings.get_account_setting(
+            self.account, 'no_log_for').split()
         if self.jid in no_log_for:
             oldlog = False
         log = widget.get_active()
@@ -787,8 +784,8 @@ class HistoryWindow:
         if log and self.jid in no_log_for:
             no_log_for.remove(self.jid)
         if oldlog != log:
-            app.config.set_per(
-                'accounts', self.account, 'no_log_for', ' '.join(no_log_for))
+            app.settings.set_account_setting(
+                self.account, 'no_log_for', ' '.join(no_log_for))
 
     def on_show_status_checkbutton_toggled(self, widget):
         # reload logs
@@ -798,7 +795,7 @@ class HistoryWindow:
         """
         Load chat history of the specified jid
         """
-        self.jid_entry.get_child().set_text(jid)
+        self._ui.query_entry.get_child().set_text(jid)
         if account and account not in self.accounts_seen_online:
             # Update dict to not only show bare jid
             GLib.idle_add(next, self._fill_completion_dict())
@@ -806,13 +803,13 @@ class HistoryWindow:
             # Only in that case because it's called by
             # self._fill_completion_dict() otherwise
             self._load_history(jid, account)
-        self.results_window.set_property('visible', False)
+        self._ui.results_scrolledwindow.set_visible(False)
 
     def save_state(self):
-        x, y = self.window.get_window().get_root_origin()
-        width, height = self.window.get_size()
+        x, y = self.get_window().get_root_origin()
+        width, height = self.get_size()
 
-        app.config.set('history_window_x-position', x)
-        app.config.set('history_window_y-position', y)
-        app.config.set('history_window_width', width)
-        app.config.set('history_window_height', height)
+        app.settings.set('history_window_x-position', x)
+        app.settings.set('history_window_y-position', y)
+        app.settings.set('history_window_width', width)
+        app.settings.set('history_window_height', height)
