@@ -1,47 +1,80 @@
-# -*- coding:utf-8 -*-
-## src/history_manager.py
-##
-## Copyright (C) 2006 Dimitur Kirov <dkirov AT gmail.com>
-## Copyright (C) 2006-2007 Jean-Marie Traissard <jim AT lapin.org>
-##                         Nikos Kouremenos <kourem AT gmail.com>
-## Copyright (C) 2006-2014 Yann Leboulanger <asterix AT lagaule.org>
-## Copyright (C) 2007 Stephan Erb <steve-e AT h3c.de>
-## Copyright (C) 2008 Jonathan Schleifer <js-gajim AT webkeks.org>
-##
-## This file is part of Gajim.
-##
-## Gajim is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published
-## by the Free Software Foundation; version 3 only.
-##
-## Gajim is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with Gajim. If not, see <http://www.gnu.org/licenses/>.
-##
+# Copyright (C) 2006 Dimitur Kirov <dkirov AT gmail.com>
+# Copyright (C) 2006-2007 Jean-Marie Traissard <jim AT lapin.org>
+#                         Nikos Kouremenos <kourem AT gmail.com>
+# Copyright (C) 2006-2014 Yann Leboulanger <asterix AT lagaule.org>
+# Copyright (C) 2007 Stephan Erb <steve-e AT h3c.de>
+# Copyright (C) 2008 Jonathan Schleifer <js-gajim AT webkeks.org>
+# Copyright (C) 2018 Philipp Hörist <philipp AT hoerist.com>
+#
+# This file is part of Gajim.
+#
+# Gajim is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published
+# by the Free Software Foundation; version 3 only.
+#
+# Gajim is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Gajim. If not, see <http://www.gnu.org/licenses/>.
 
-## NOTE: some method names may match those of logger.py but that's it
-## someday (TM) should have common class
-## that abstracts db connections and helpers on it
-## the same can be said for history_window.py
+# NOTE: some method names may match those of logger.py but that's it
+# someday (TM) should have common class
+# that abstracts db connections and helpers on it
+# the same can be said for history.py
 
 import os
 import sys
+import time
+import getopt
+import sqlite3
+from enum import IntEnum, unique
+
 import gi
-gi.require_version('Gtk', '3.0')
+
+try:
+    gi.require_versions({'Gtk': '3.0'})
+except ValueError as error:
+    sys.exit('Missing dependency: %s' % error)
+
+# pylint: disable=C0413
 from gi.repository import Gtk
 from gi.repository import Gdk
 from gi.repository import GLib
-import time
+from gi.repository import Gio
+from gi.repository import Pango
 
-import getopt
-from gajim.common import i18n
+import gajim.gui
+from gajim.common import app
+from gajim.common import configpaths
+from gajim.common.i18n import _
+from gajim.common.i18n import ngettext
+from gajim.common.const import StyleAttr
+from gajim.common.const import JIDConstant
+from gajim.common.const import KindConstant
+from gajim.common.const import ShowConstant
+from gajim.common.settings import Settings
 
-def parseOpts():
-    config_path = None
+
+def is_standalone():
+    # Determine if we are in standalone mode
+    if Gio.Application.get_default() is None:
+        return True
+    if __name__ == '__main__':
+        return True
+    return False
+
+
+def init_gtk():
+    gajim.gui.init('gtk')
+    from gajim.gui import exception
+    exception.init()
+
+
+if is_standalone():
+    init_gtk()
 
     try:
         shortargs = 'hvsc:l:p:'
@@ -61,22 +94,22 @@ def parseOpts():
                 '\n  -c, --config-path  ' + _('Choose folder for logfile') + '\n')
             sys.exit()
         elif o in ('-c', '--config-path'):
-            config_path = a
-    return config_path
+            configpaths.set_config_root(a)
 
-config_path = parseOpts()
-del parseOpts
+    configpaths.init()
+    app.settings = Settings()
+    app.settings.init()
+    app.load_css_config()
 
-import gajim.common.configpaths
-gajim.common.configpaths.gajimpaths.init(config_path)
-del config_path
-from gajim.common import app
-from gajim import gtkgui_helpers
-from gajim.common.logger import LOG_DB_PATH, JIDConstant, KindConstant
 from gajim.common import helpers
-from gajim import dialogs
-
-from enum import IntEnum, unique
+from gajim.gui.dialogs import ErrorDialog
+from gajim.gui.dialogs import ConfirmationDialog
+from gajim.gui.dialogs import DialogButton
+from gajim.gui.filechoosers import FileSaveDialog
+from gajim.gui.util import convert_rgb_to_hex
+from gajim.gui.util import get_builder
+from gajim.gui.util import get_app_icon_list
+# pylint: enable=C0413
 
 @unique
 class Column(IntEnum):
@@ -86,41 +119,24 @@ class Column(IntEnum):
     NICKNAME = 5
 
 
-import sqlite3 as sqlite
-
-
 class HistoryManager:
     def __init__(self):
-        pixs = []
-        for size in (16, 32, 48, 64, 128):
-            pix = gtkgui_helpers.get_icon_pixmap('org.gajim.Gajim', size)
-            if pix:
-                pixs.append(pix)
-        if pixs:
-            # set the icon to all windows
-            Gtk.Window.set_default_icon_list(pixs)
-
-        if not os.path.exists(LOG_DB_PATH):
-            dialogs.ErrorDialog(_('Cannot find history logs database'),
-                    '%s does not exist.' % LOG_DB_PATH)
+        log_db_path = configpaths.get('LOG_DB')
+        if not log_db_path.exists():
+            ErrorDialog(_('Cannot find history logs database'),
+                        _('%s does not exist.') % log_db_path)
             sys.exit()
 
-        xml = gtkgui_helpers.get_gtk_builder('history_manager.ui')
-        self.window = xml.get_object('history_manager_window')
-        self.jids_listview = xml.get_object('jids_listview')
-        self.logs_listview = xml.get_object('logs_listview')
-        self.search_results_listview = xml.get_object('search_results_listview')
-        self.search_entry = xml.get_object('search_entry')
-        self.logs_scrolledwindow = xml.get_object('logs_scrolledwindow')
-        self.search_results_scrolledwindow = xml.get_object(
-                'search_results_scrolledwindow')
-        self.welcome_vbox = xml.get_object('welcome_vbox')
+        self._ui = get_builder('history_manager.ui')
+        Gtk.Window.set_default_icon_list(get_app_icon_list(
+            self._ui.history_manager_window))
 
         self.jids_already_in = []  # holds jids that we already have in DB
         self.AT_LEAST_ONE_DELETION_DONE = False
 
-        self.con = sqlite.connect(LOG_DB_PATH, timeout=20.0,
-                isolation_level='IMMEDIATE')
+        self.con = sqlite3.connect(
+            log_db_path, timeout=20.0, isolation_level='IMMEDIATE')
+        self.con.execute("PRAGMA secure_delete=1")
         self.cur = self.con.cursor()
 
         self._init_jids_listview()
@@ -129,36 +145,36 @@ class HistoryManager:
 
         self._fill_jids_listview()
 
-        self.search_entry.grab_focus()
+        self._ui.search_entry.grab_focus()
 
-        self.window.show_all()
+        self._ui.history_manager_window.show_all()
 
-        xml.connect_signals(self)
+        self._ui.connect_signals(self)
 
     def _init_jids_listview(self):
         self.jids_liststore = Gtk.ListStore(str, str)  # jid, jid_id
-        self.jids_listview.set_model(self.jids_liststore)
-        self.jids_listview.get_selection().set_mode(Gtk.SelectionMode.MULTIPLE)
+        self._ui.jids_listview.set_model(self.jids_liststore)
+        self._ui.jids_listview.get_selection().set_mode(Gtk.SelectionMode.MULTIPLE)
 
         renderer_text = Gtk.CellRendererText()  # holds jid
-        col = Gtk.TreeViewColumn(_('JID'), renderer_text, text=0)
-        self.jids_listview.append_column(col)
+        col = Gtk.TreeViewColumn(_('XMPP Address'), renderer_text, text=0)
+        self._ui.jids_listview.append_column(col)
 
-        self.jids_listview.get_selection().connect('changed',
+        self._ui.jids_listview.get_selection().connect('changed',
                 self.on_jids_listview_selection_changed)
 
     def _init_logs_listview(self):
         # log_line_id(HIDDEN), jid_id(HIDDEN), time, message, subject, nickname
         self.logs_liststore = Gtk.ListStore(str, str, str, str, str, str)
-        self.logs_listview.set_model(self.logs_liststore)
-        self.logs_listview.get_selection().set_mode(Gtk.SelectionMode.MULTIPLE)
+        self._ui.logs_listview.set_model(self.logs_liststore)
+        self._ui.logs_listview.get_selection().set_mode(Gtk.SelectionMode.MULTIPLE)
 
         renderer_text = Gtk.CellRendererText()  # holds time
         col = Gtk.TreeViewColumn(_('Date'), renderer_text, text=Column.UNIXTIME)
         # user can click this header and sort
         col.set_sort_column_id(Column.UNIXTIME)
         col.set_resizable(True)
-        self.logs_listview.append_column(col)
+        self._ui.logs_listview.append_column(col)
 
         renderer_text = Gtk.CellRendererText()  # holds nickname
         col = Gtk.TreeViewColumn(_('Nickname'), renderer_text, text=Column.NICKNAME)
@@ -167,89 +183,97 @@ class HistoryManager:
         col.set_resizable(True)
         col.set_visible(False)
         self.nickname_col_for_logs = col
-        self.logs_listview.append_column(col)
+        self._ui.logs_listview.append_column(col)
 
         renderer_text = Gtk.CellRendererText()  # holds message
+        renderer_text.set_property('width_chars', 60)
+        renderer_text.set_property('ellipsize', Pango.EllipsizeMode.END)
         col = Gtk.TreeViewColumn(_('Message'), renderer_text, markup=Column.MESSAGE)
         # user can click this header and sort
         col.set_sort_column_id(Column.MESSAGE)
         col.set_resizable(True)
         self.message_col_for_logs = col
-        self.logs_listview.append_column(col)
+        self._ui.logs_listview.append_column(col)
 
         renderer_text = Gtk.CellRendererText()  # holds subject
         col = Gtk.TreeViewColumn(_('Subject'), renderer_text, text=Column.SUBJECT)
-        col.set_sort_column_id(Column.SUBJECT)  # user can click this header and sort
+        # user can click this header and sort
+        col.set_sort_column_id(Column.SUBJECT)
         col.set_resizable(True)
         col.set_visible(False)
         self.subject_col_for_logs = col
-        self.logs_listview.append_column(col)
+        self._ui.logs_listview.append_column(col)
 
     def _init_search_results_listview(self):
         # log_line_id (HIDDEN), jid, time, message, subject, nickname
         self.search_results_liststore = Gtk.ListStore(int, str, str, str, str,
             str)
-        self.search_results_listview.set_model(self.search_results_liststore)
+        self._ui.search_results_listview.set_model(self.search_results_liststore)
 
         renderer_text = Gtk.CellRendererText()  # holds JID (who said this)
-        col = Gtk.TreeViewColumn(_('JID'), renderer_text, text=1)
-        col.set_sort_column_id(1)  # user can click this header and sort
+        col = Gtk.TreeViewColumn(_('XMPP Address'), renderer_text, text=1)
+        # user can click this header and sort
+        col.set_sort_column_id(1)
         col.set_resizable(True)
-        self.search_results_listview.append_column(col)
+        self._ui.search_results_listview.append_column(col)
 
         renderer_text = Gtk.CellRendererText()  # holds time
         col = Gtk.TreeViewColumn(_('Date'), renderer_text, text=Column.UNIXTIME)
         # user can click this header and sort
         col.set_sort_column_id(Column.UNIXTIME)
         col.set_resizable(True)
-        self.search_results_listview.append_column(col)
+        self._ui.search_results_listview.append_column(col)
 
         renderer_text = Gtk.CellRendererText()  # holds message
+        renderer_text.set_property('width_chars', 60)
+        renderer_text.set_property('ellipsize', Pango.EllipsizeMode.END)
         col = Gtk.TreeViewColumn(_('Message'), renderer_text, text=Column.MESSAGE)
-        col.set_sort_column_id(Column.MESSAGE)  # user can click this header and sort
+        # user can click this header and sort
+        col.set_sort_column_id(Column.MESSAGE)
         col.set_resizable(True)
-        self.search_results_listview.append_column(col)
+        self._ui.search_results_listview.append_column(col)
 
         renderer_text = Gtk.CellRendererText()  # holds subject
         col = Gtk.TreeViewColumn(_('Subject'), renderer_text, text=Column.SUBJECT)
-        col.set_sort_column_id(Column.SUBJECT)  # user can click this header and sort
+        # user can click this header and sort
+        col.set_sort_column_id(Column.SUBJECT)
         col.set_resizable(True)
-        self.search_results_listview.append_column(col)
+        self._ui.search_results_listview.append_column(col)
 
         renderer_text = Gtk.CellRendererText()  # holds nickname
         col = Gtk.TreeViewColumn(_('Nickname'), renderer_text, text=Column.NICKNAME)
         # user can click this header and sort
         col.set_sort_column_id(Column.NICKNAME)
         col.set_resizable(True)
-        self.search_results_listview.append_column(col)
+        self._ui.search_results_listview.append_column(col)
 
     def on_history_manager_window_delete_event(self, widget, event):
         if not self.AT_LEAST_ONE_DELETION_DONE:
-            if __name__ == '__main__':
+            if is_standalone():
                 Gtk.main_quit()
             return
 
-        def on_yes(clicked):
+        def _on_yes():
             self.cur.execute('VACUUM')
             self.con.commit()
-            if __name__ == '__main__':
+            if is_standalone():
                 Gtk.main_quit()
 
-        def on_no():
-            if __name__ == '__main__':
+        def _on_no():
+            if is_standalone():
                 Gtk.main_quit()
 
-        dialog = dialogs.YesNoDialog(
-            _('Do you want to clean up the database? '
-            '(STRONGLY NOT RECOMMENDED IF GAJIM IS RUNNING)'),
-            _('Normally allocated database size will not be freed, '
-                'it will just become reusable. If you really want to reduce '
-                'database filesize, click YES, else click NO.'
-                '\n\nIn case you click YES, please wait…'),
-            on_response_yes=on_yes, on_response_no=on_no)
-        dialog.set_title(_('Database Cleanup'))
-        button_box = dialog.get_children()[0].get_children()[1]
-        button_box.get_children()[0].grab_focus()
+        ConfirmationDialog(
+            _('Database Cleanup'),
+            _('Clean up the database?'),
+            _('This is STRONGLY NOT RECOMMENDED IF GAJIM IS RUNNING.\n'
+              'Normally, the allocated database size will not be freed, it '
+              'will just become reusable. This operation may take a while.'),
+            [DialogButton.make('Cancel',
+                               callback=_on_no),
+             DialogButton.make('Remove',
+                               text=_('_Cleanup'),
+                               callback=_on_yes)]).show()
 
     def _fill_jids_listview(self):
         # get those jids that have at least one entry in logs
@@ -262,16 +286,16 @@ class HistoryManager:
             self.jids_liststore.append([row[0], str(row[1])])  # jid, jid_id
 
     def on_jids_listview_selection_changed(self, widget, data=None):
-        liststore, list_of_paths = self.jids_listview.get_selection()\
+        liststore, list_of_paths = self._ui.jids_listview.get_selection()\
                 .get_selected_rows()
 
         self.logs_liststore.clear()
         if not list_of_paths:
             return
 
-        self.welcome_vbox.hide()
-        self.search_results_scrolledwindow.hide()
-        self.logs_scrolledwindow.show()
+        self._ui.welcome_box.hide()
+        self._ui.search_results_scrolledwindow.hide()
+        self._ui.logs_scrolledwindow.show()
 
         list_of_rowrefs = []
         for path in list_of_paths:  # make them treerowrefs (it's needed)
@@ -315,7 +339,7 @@ class HistoryManager:
         If jid is gajim@conf/nkour it's likely a pm one, how we know gajim@conf
         is not a normal guy and nkour is not his resource? We ask if gajim@conf
         is already in jids (with type room jid). This fails if user disables
-        logging for room and only enables for pm (so higly unlikely) and if we
+        logging for room and only enables for pm (so highly unlikely) and if we
         fail we do not go chaos (user will see the first pm as if it was message
         in room's public chat) and after that everything is ok
         """
@@ -326,8 +350,7 @@ class HistoryManager:
         row = self.cur.fetchone()
         if row is None:
             return False
-        else:
-            return True
+        return True
 
     def _jid_is_room_type(self, jid):
         """
@@ -335,12 +358,7 @@ class HistoryManager:
         """
         self.cur.execute('SELECT type FROM jids WHERE jid = ?', (jid,))
         row = self.cur.fetchone()
-        if row is None:
-            raise
-        elif row[0] == JIDConstant.ROOM_TYPE:
-            return True
-        else:  # normal type
-            return False
+        return row[0] == JIDConstant.ROOM_TYPE
 
     def _fill_logs_listview(self, jid):
         """
@@ -366,6 +384,7 @@ class HistoryManager:
             self.nickname_col_for_logs.set_visible(False)
             self.subject_col_for_logs.set_visible(True)
 
+        format_ = helpers.from_one_line(app.settings.get('time_stamp'))
         for row in results:
             # exposed in UI (TreeViewColumns) are only
             # time, message, subject, nickname
@@ -374,36 +393,39 @@ class HistoryManager:
             log_line_id, jid_id, time_, kind, message, subject, nickname, \
                 show = row
             try:
-                time_ = time.strftime('%x', time.localtime(float(time_)))
+                time_ = time.strftime(format_, time.localtime(float(time_)))
             except ValueError:
                 pass
             else:
                 color = None
                 if kind in (KindConstant.SINGLE_MSG_RECV,
-                KindConstant.CHAT_MSG_RECV, KindConstant.GC_MSG):
-                    # it is the other side
-                    color = app.config.get('inmsgcolor')  # so incoming color
+                            KindConstant.CHAT_MSG_RECV,
+                            KindConstant.GC_MSG):
+                    color = app.css_config.get_value(
+                        '.gajim-incoming-nickname', StyleAttr.COLOR)
                 elif kind in (KindConstant.SINGLE_MSG_SENT,
-                KindConstant.CHAT_MSG_SENT):  # it is us
-                    color = app.config.get('outmsgcolor')  # so outgoing color
+                              KindConstant.CHAT_MSG_SENT):
+                    color = app.css_config.get_value(
+                        '.gajim-outgoing-nickname', StyleAttr.COLOR)
                 elif kind in (KindConstant.STATUS,
-                KindConstant.GCSTATUS):  # is is statuses
-                    # so status color
-                    color = app.config.get('statusmsgcolor')
+                              KindConstant.GCSTATUS):
+                    color = app.css_config.get_value(
+                        '.gajim-status-message', StyleAttr.COLOR)
                     # include status into (status) message
                     if message is None:
                         message = ''
                     else:
                         message = ' : ' + message
-                    message = helpers.get_uf_show(app.SHOW_LIST[show]) + \
-                        message
+
+                    message = helpers.get_uf_show(ShowConstant(show)) + message
 
                 message_ = '<span'
                 if color:
-                    message_ += ' foreground="%s"' % color
+                    message_ += ' foreground="%s"' % convert_rgb_to_hex(color)
                 message_ += '>%s</span>' % GLib.markup_escape_text(message)
-                self.logs_liststore.append((str(log_line_id), str(jid_id),
-                    time_, message_, subject, nickname))
+                self.logs_liststore.append(
+                    (str(log_line_id), str(jid_id),
+                     time_, message_, subject, nickname))
 
     def _fill_search_results_listview(self, text):
         """
@@ -419,6 +441,7 @@ class HistoryManager:
                 ''', (like_sql, like_sql))
 
         results = self.cur.fetchall()
+        format_ = helpers.from_one_line(app.settings.get('time_stamp'))
         for row in results:
             # exposed in UI (TreeViewColumns) are only
             # JID, time, message, subject, nickname
@@ -426,7 +449,7 @@ class HistoryManager:
             # log_line_id, jid (from jid_id), time, message, subject, nickname
             log_line_id, jid_id, time_, message, subject, nickname = row
             try:
-                time_ = time.strftime('%x', time.localtime(float(time_)))
+                time_ = time.strftime(format_, time.localtime(float(time_)))
             except ValueError:
                 pass
             else:
@@ -436,44 +459,33 @@ class HistoryManager:
                         message, subject, nickname))
 
     def on_logs_listview_key_press_event(self, widget, event):
-        liststore, list_of_paths = self.logs_listview.get_selection()\
+        liststore, list_of_paths = self._ui.logs_listview.get_selection()\
                 .get_selected_rows()
         if event.keyval == Gdk.KEY_Delete:
             self._delete_logs(liststore, list_of_paths)
 
     def on_listview_button_press_event(self, widget, event):
         if event.button == 3:  # right click
-            xml = gtkgui_helpers.get_gtk_builder('history_manager.ui',
-                'context_menu')
+            _ui = get_builder('history_manager.ui', ['context_menu'])
             if Gtk.Buildable.get_name(widget) != 'jids_listview':
-                xml.get_object('export_menuitem').hide()
-            xml.get_object('delete_menuitem').connect('activate',
+                _ui.export_menuitem.hide()
+            _ui.delete_menuitem.connect('activate',
                     self.on_delete_menuitem_activate, widget)
 
-            xml.connect_signals(self)
-            xml.get_object('context_menu').popup(None, None, None, None,
+            _ui.connect_signals(self)
+            _ui.context_menu.popup(None, None, None, None,
                     event.button, event.time)
             return True
 
     def on_export_menuitem_activate(self, widget):
-        xml = gtkgui_helpers.get_gtk_builder('history_manager.ui',
-            'filechooserdialog')
-        xml.connect_signals(self)
+        FileSaveDialog(self._on_export,
+                       transient_for=self._ui.history_manager_window,
+                       modal=True)
 
-        dlg = xml.get_object('filechooserdialog')
-        dlg.set_title(_('Exporting History Logs…'))
-        dlg.set_current_folder(app.HOME_DIR)
-        dlg.props.do_overwrite_confirmation = True
-        response = dlg.run()
-
-        if response == Gtk.ResponseType.OK:  # user want us to export ;)
-            liststore, list_of_paths = self.jids_listview.get_selection()\
-                    .get_selected_rows()
-            path_to_file = dlg.get_filename()
-            self._export_jids_logs_to_file(liststore, list_of_paths,
-                path_to_file)
-
-        dlg.destroy()
+    def _on_export(self, filename):
+        liststore, list_of_paths = self._ui.jids_listview.get_selection()\
+                .get_selected_rows()
+        self._export_jids_logs_to_file(liststore, list_of_paths, filename)
 
     def on_delete_menuitem_activate(self, widget, listview):
         widget_name = Gtk.Buildable.get_name(listview)
@@ -486,7 +498,7 @@ class HistoryManager:
             return
 
     def on_jids_listview_key_press_event(self, widget, event):
-        liststore, list_of_paths = self.jids_listview.get_selection()\
+        liststore, list_of_paths = self._ui.jids_listview.get_selection()\
                 .get_selected_rows()
         if event.keyval == Gdk.KEY_Delete:
             self._delete_jid_logs(liststore, list_of_paths)
@@ -545,7 +557,7 @@ class HistoryManager:
         if paths_len == 0:  # nothing is selected
             return
 
-        def on_ok(liststore, list_of_paths):
+        def on_ok():
             # delete all rows from db that match jid_id
             list_of_rowrefs = []
             for path in list_of_paths:  # make them treerowrefs (it's needed)
@@ -573,28 +585,24 @@ class HistoryManager:
 
             self.AT_LEAST_ONE_DELETION_DONE = True
 
-        if paths_len == 1:
-            jid_id = '<i>%s</i>' % liststore[list_of_paths[0]][0]
-            pri_text = _('Do you wish to delete all correspondence with %(jid)s?') \
-                % {'jid': jid_id}
-        else:
-            pri_text = _(
-                'Do you wish to delete all correspondence with the selected contacts?')
-        dialog = dialogs.ConfirmationDialog('',
-            _('This can not be undone.'), on_response_ok=(on_ok,
-            liststore, list_of_paths))
-        dialog.set_title(_('Deletion Confirmation'))
-        dialog.set_markup(pri_text)
-        ok_button = dialog.get_children()[0].get_children()[1].get_children()[0]
-        ok_button.grab_focus()
-        dialog.set_transient_for(self.window)
+        ConfirmationDialog(
+            _('Delete'),
+            ngettext('Delete Conversation', 'Delete Conversations', paths_len),
+            ngettext('Do you want to permanently delete this '
+                     'conversation with <b>%s</b>?',
+                     'Do you want to permanently delete these conversations?',
+                     paths_len, liststore[list_of_paths[0]][0]),
+            [DialogButton.make('Cancel'),
+             DialogButton.make('Delete',
+                               callback=on_ok)],
+            transient_for=self._ui.history_manager_window).show()
 
     def _delete_logs(self, liststore, list_of_paths):
         paths_len = len(list_of_paths)
         if paths_len == 0:  # nothing is selected
             return
 
-        def on_ok(liststore, list_of_paths):
+        def on_ok():
             # delete rows from db that match log_line_id
             list_of_rowrefs = []
             for path in list_of_paths:  # make them treerowrefs (it's needed)
@@ -616,25 +624,25 @@ class HistoryManager:
 
             self.AT_LEAST_ONE_DELETION_DONE = True
 
-        pri_text = i18n.ngettext(
-            'Do you really want to delete the selected message?',
-            'Do you really want to delete the selected messages?', paths_len)
-        dialog = dialogs.ConfirmationDialog(pri_text,
-            _('This is an irreversible operation.'), on_response_ok=(on_ok,
-            liststore, list_of_paths))
-        dialog.set_title(_('Deletion Confirmation'))
-        ok_button = dialog.get_children()[0].get_children()[1].get_children()[0]
-        ok_button.grab_focus()
-        dialog.set_transient_for(self.window)
+        ConfirmationDialog(
+            _('Delete'),
+            ngettext('Delete Message', 'Delete Messages', paths_len),
+            ngettext('Do you want to permanently delete this message?',
+                     'Do you want to permanently delete these messages?',
+                     paths_len),
+            [DialogButton.make('Cancel'),
+             DialogButton.make('Delete',
+                               callback=on_ok)],
+            transient_for=self._ui.history_manager_window).show()
 
     def on_search_db_button_clicked(self, widget):
-        text = self.search_entry.get_text()
+        text = self._ui.search_entry.get_text()
         if not text:
             return
 
-        self.welcome_vbox.hide()
-        self.logs_scrolledwindow.hide()
-        self.search_results_scrolledwindow.show()
+        self._ui.welcome_box.hide()
+        self._ui.logs_scrolledwindow.hide()
+        self._ui.search_results_scrolledwindow.show()
 
         self._fill_search_results_listview(text)
 
@@ -657,7 +665,7 @@ class HistoryManager:
             return
 
         path = self.jids_liststore.get_path(iter_)
-        self.jids_listview.set_cursor(path)
+        self._ui.jids_listview.set_cursor(path)
 
         iter_ = self.logs_liststore.get_iter_first()
         while iter_:
@@ -667,8 +675,8 @@ class HistoryManager:
             iter_ = self.logs_liststore.iter_next(iter_)
 
         path = self.logs_liststore.get_path(iter_)
-        self.logs_listview.scroll_to_cell(path)
-        self.logs_listview.get_selection().select_path(path)
+        self._ui.logs_listview.scroll_to_cell(path)
+        self._ui.logs_listview.get_selection().select_path(path)
 
 
 def main():
